@@ -755,6 +755,11 @@ class PGConnector(DBConnector):
                     ):
                         result["modelname"] = model["modelname"]
                         result["content"] = content["content"]
+                        match = re.search(
+                            re.escape(model["modelname"]) + r"\{\s([^\}]*)\}",
+                            content["modelname"],
+                        )
+                        result["parents"] = match.group(1).split() if match else []
                         list_result.append(result)
                         result = dict()
 
