@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 /***************************************************************************
     begin                :    25/09/17
@@ -293,12 +292,15 @@ class TestImport(unittest.TestCase):
         importer = iliimporter.Importer()
         importer.tool = DbIliMode.ili2pg
         importer.configuration = iliimporter_config(importer.tool)
-        importer.configuration.ilifile = testdata_path("ilimodels/OeVBasketTest_V1.ili")
-        importer.configuration.ilimodels = "OeVBasketTest"
+        importer.configuration.ilifile = testdata_path(
+            "ilimodels/PipeBasketTest_V1.ili"
+        )
+        importer.configuration.ilimodels = "PipeBasketTest"
         importer.configuration.dbschema = "any_{:%Y%m%d%H%M%S%f}".format(
             datetime.datetime.now()
         )
         importer.configuration.inheritance = "smart2"
+        importer.configuration.create_basket_col = True
         importer.stdout.connect(self.print_info)
         importer.stderr.connect(self.print_error)
         assert importer.run() == iliimporter.Importer.SUCCESS
@@ -313,7 +315,7 @@ class TestImport(unittest.TestCase):
         dataImporter.configuration = ilidataimporter_config(importer.tool)
         dataImporter.configuration.dbschema = importer.configuration.dbschema
         dataImporter.configuration.xtffile = testdata_path(
-            "xtf/test_oevbaskettest_v1_winti.xtf"
+            "xtf/test_pipebaskettest_v1_winti.xtf"
         )
         dataImporter.configuration.with_importtid = True
         dataImporter.stdout.connect(self.print_info)
@@ -329,7 +331,7 @@ class TestImport(unittest.TestCase):
         cursor.execute(
             """
                 SELECT {}
-                FROM {}.haltestelle
+                FROM {}.station
                 WHERE aname = 'Oberwinterthur'
             """.format(
                 db_connector.tilitid, dataImporter.configuration.dbschema
@@ -337,19 +339,22 @@ class TestImport(unittest.TestCase):
         )
         record = next(cursor)
         assert record is not None
-        assert record[0] == "59ba6620-6cbc-452f-91c2-ea2574b47330"
+        assert record[0].lower() == "59ba6620-6cbc-452f-91c2-ea2574b47330"
 
     def test_tid_import_geopackage(self):
         # Schema Import
         importer = iliimporter.Importer()
         importer.tool = DbIliMode.ili2gpkg
         importer.configuration = iliimporter_config(importer.tool)
-        importer.configuration.ilifile = testdata_path("ilimodels/OeVBasketTest_V1.ili")
-        importer.configuration.ilimodels = "OeVBasketTest"
+        importer.configuration.ilifile = testdata_path(
+            "ilimodels/PipeBasketTest_V1.ili"
+        )
+        importer.configuration.ilimodels = "PipeBasketTest"
         importer.configuration.dbfile = os.path.join(
             self.basetestpath, "tmp_basket_gpkg.gpkg"
         )
         importer.configuration.inheritance = "smart2"
+        importer.configuration.create_basket_col = True
         importer.stdout.connect(self.print_info)
         importer.stderr.connect(self.print_error)
         assert importer.run() == iliimporter.Importer.SUCCESS
@@ -364,7 +369,7 @@ class TestImport(unittest.TestCase):
         dataImporter.configuration = ilidataimporter_config(importer.tool)
         dataImporter.configuration.dbfile = importer.configuration.dbfile
         dataImporter.configuration.xtffile = testdata_path(
-            "xtf/test_oevbaskettest_v1_winti.xtf"
+            "xtf/test_pipebaskettest_v1_winti.xtf"
         )
         dataImporter.configuration.with_importtid = True
         dataImporter.stdout.connect(self.print_info)
@@ -378,7 +383,7 @@ class TestImport(unittest.TestCase):
         cursor.execute(
             """
                 SELECT {}
-                FROM haltestelle
+                FROM station
                 WHERE aname = 'Oberwinterthur'
             """.format(
                 db_connector.tilitid, dataImporter.configuration.dbschema
@@ -386,19 +391,22 @@ class TestImport(unittest.TestCase):
         )
         record = next(cursor)
         assert record is not None
-        assert record[0] == "59ba6620-6cbc-452f-91c2-ea2574b47330"
+        assert record[0].lower() == "59ba6620-6cbc-452f-91c2-ea2574b47330"
 
     def test_tid_import_mssql(self):
         # Schema Import
         importer = iliimporter.Importer()
         importer.tool = DbIliMode.ili2mssql
         importer.configuration = iliimporter_config(importer.tool)
-        importer.configuration.ilifile = testdata_path("ilimodels/OeVBasketTest_V1.ili")
-        importer.configuration.ilimodels = "OeVBasketTest"
+        importer.configuration.ilifile = testdata_path(
+            "ilimodels/PipeBasketTest_V1.ili"
+        )
+        importer.configuration.ilimodels = "PipeBasketTest"
         importer.configuration.dbschema = "baskets_{:%Y%m%d%H%M%S%f}".format(
             datetime.datetime.now()
         )
         importer.configuration.inheritance = "smart2"
+        importer.configuration.create_basket_col = True
         importer.stdout.connect(self.print_info)
         importer.stderr.connect(self.print_error)
 
@@ -414,7 +422,7 @@ class TestImport(unittest.TestCase):
         dataImporter.configuration = ilidataimporter_config(importer.tool)
         dataImporter.configuration.dbschema = importer.configuration.dbschema
         dataImporter.configuration.xtffile = testdata_path(
-            "xtf/test_oevbaskettest_v1_winti.xtf"
+            "xtf/test_pipebaskettest_v1_winti.xtf"
         )
         dataImporter.configuration.with_importtid = True
         dataImporter.stdout.connect(self.print_info)
@@ -434,7 +442,7 @@ class TestImport(unittest.TestCase):
         cursor.execute(
             """
                 SELECT {}
-                FROM {}.haltestelle
+                FROM {}.station
                 WHERE aname = 'Oberwinterthur'
             """.format(
                 db_connector.tilitid, dataImporter.configuration.dbschema
@@ -442,7 +450,7 @@ class TestImport(unittest.TestCase):
         )
         record = next(cursor)
         assert record is not None
-        assert record[0] == "59ba6620-6cbc-452f-91c2-ea2574b47330"
+        assert record[0].lower() == "59ba6620-6cbc-452f-91c2-ea2574b47330"
 
     def print_info(self, text):
         logging.info(text)
